==> language-env_0.64.tar.gz: language-env-0.63/ja/dot.xemacs/init.el.pl <==
;   comment -*-coding: euc-jp;-*-
xemacs21 NO SETTEI DESU.
END
xemacs21 Ǥ
END
print <<'EOF';
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; ܸɽ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (featurep 'mule)
    (progn
      (set-language-environment "Japanese")
      (prefer-coding-system 'euc-jp-unix)
      (set-keyboard-coding-system 'euc-jp-unix)
      (if (not window-system) (set-terminal-coding-system 'euc-jp-unix))
      ;;
      ))
; ܸ info ʸʤ褦
(auto-compression-mode t)
; xemacs  shell-mode  ܸ EUC Ȥ褦ˤ
(if (featurep 'xemacs)
    (add-hook 'shell-mode-hook (function
       (lambda () (set-buffer-process-coding-system 'euc-japan 'euc-japan))))
)
; ܸ grep
(if (file-exists-p "/usr/bin/lgrep")
    (setq grep-command "lgrep -n ")
)
EOF

$emacs_comment = 
";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;";

#
#  ʴѴ
#
foreach $im ("Canna", "Wnn", "SKK", "Anthy", "PRIME") {
	&disp("$im NO JOUTAI: ", "$im ξ: ");
	if ($IM_EXIST{$im} == 0) {
		&disp("TSUKAEMASEN.\n", "Ȥޤ\n");
	} elsif ($IM_HOST{$im} eq "") {
		&disp("local\n", "\n");
	} else {
		&disp("host = $SERVER_HOST\n", "ۥ = $IM_HOST{$im}\n");
	}
}

$d = 6;
if ($IM_DEFAULT eq "Canna") {$d = 1;}
if ($IM_DEFAULT eq "Wnn")   {$d = 2;}
if ($IM_DEFAULT eq "SKK")   {$d = 3;}
if ($IM_DEFAULT eq "Anthy") {$d = 4;}
if ($IM_DEFAULT eq "PRIME") {$d = 5;}
$a = &select(
	"emacs DEHA, KANJI HENKAN NIHA DORE WO TSUKAI MASUKA? " .
	"1=Canna 2=Wnn 3=SKK 4=Anthy 5=PRIME 6=none ",
	"emacs ǤϡѴˤϤɤȤޤ " .
	"1=Canna 2=Wnn 3=SKK 4=Anthy 5=PRIME 6=none ",
	6, $d);
if ($a == 1) {
	&emacs_canna($IM_HOST{'Canna'});
} elsif ($a == 2) {
	&emacs_wnn($IM_HOST{'Wnn'});
} elsif ($a == 3) {
	&emacs_skk($IM_HOST{'SKK'});
} elsif ($a == 4) {
	&emacs_anthy;
} elsif ($a == 5) {
	&emacs_prime;
}

sub emacs_canna ($) {
	my $server;
	$server=$_[0];
	print
		"$emacs_comment\n" .
		";; Ѵ (canna) \n" .
		"$emacs_comment\n";
	if ($server ne "") {print "(setq canna-server \"$server\")";}
	print
		"(set-input-method 'japanese-canna)\n" .
		"(global-set-key \"\\C-o\" 'toggle-input-method)\n" .
		"(toggle-input-method nil)\n";
	addlist("xemacs21-mule-canna-wnn");
}

sub emacs_wnn($) {
	my $server;
	$server=$_[0];
	print
		"$emacs_comment\n" .
		";; Ѵ (wnn) \n" .
		"$emacs_comment\n" ;
	if ($server ne "") {print "(set-wnn-host-name \"$server\")\n";}
	print
		"(set-input-method 'japanese-egg-wnn)\n" .
		"(toggle-input-method nil)\n" ;
	addlist("xemacs21-mule-canna-wnn");
}

sub emacs_skk($) {
	my $server;
	$server=$_[0];
	system("/usr/bin/touch ~/.skk-jisyo");
	print
		"$emacs_comment\n" .
		";; Ѵ (skk) \n" .
		"$emacs_comment\n";
	if ($server ne "") {print "(setq skk-server-host \"$server\")\n";}
	print
		"(set-input-method \"japanese-skk\")\n" .
		"(toggle-input-method nil)\n";
	if (!isinstalled("xemacs21-mule.*")) {
		addlist("xemacs21-mule-canna-wnn");
	}
}

sub emacs_anthy {
	print
		"$emacs_comment\n" .
		";; Ѵ (Anthy) \n" .
		"$emacs_comment\n";
	print
		"(set-input-method \"japanese-anthy\")\n" .
		"(toggle-input-method nil)\n";
	addlist("anthy-el");
}

sub emacs_prime {
        print
		"$emacs_comment\n" .
		";; ʴѴ(PRIME)\n" .
		"$emacs_comment\n";
	print
		"(set-input-method \"japanese-prime\")\n" .
		"(toggle-input-method nil)\n";
	addlist("prime-el")
}

if (!$EXTENDED) {return;}
print <<'EOF';
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; XǤΥ顼ɽ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(require 'font-lock)
(if (not (featurep 'xemacs))
    (global-font-lock-mode t)
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; C ץν
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;(defun my-c-mode-common-hook ()
;   (c-set-style "linux") (setq indent-tabs-mode t) ;linux Ȥ
;      /usr/src/linux/Documentation/CodingStyle 
;   (c-set-style "k&r") ;k&rȤϤͭˤ
;   (c-set-style "gnu") ;ǥեȤ
; )
;(add-hook 'c-mode-common-hook 'my-c-mode-common-hook)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Deleteǥ֤ʸä褦ˤ
(global-set-key [delete] 'delete-char)
;; C-h ǥκʸä褦ˤ롣
;; Ȥ C-h ϥإפʤΤǡ
;; ͭˤȡإפȤȤˤ
;; M-x help  F1 Ȥɬפޤ
;(global-set-key "\C-h" 'backward-delete-char)

EOF

==> language-env_0.68.tar.gz: language-env-0.68/ja/dot.xemacs/init.el.pl <==
;   comment -*-coding: euc-jp;-*-
xemacs21 NO SETTEI DESU.
END
xemacs21 Ǥ
END
print <<'EOF';
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; ܸɽ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(when (featurep 'mule)
  (if (and (fboundp 'un-define-debian) (< emacs-major-version 22))
      (un-define-debian))
  (set-language-environment "Japanese")
  (when (or (and (fboundp 'coding-system-p)
		 (coding-system-p 'utf-8-unix))
	    (and (fboundp 'find-coding-system)
		 (find-coding-system 'utf-8-unix)))
    (prefer-coding-system 'utf-8-unix)
    (prefer-coding-system 'euc-jp-unix)
    (set-keyboard-coding-system 'utf-8-unix)
    (set-terminal-coding-system 'utf-8-unix)
    ;;
    )
  ;;(prefer-coding-system 'euc-jp-unix)
  ;;(set-keyboard-coding-system 'euc-jp-unix)
  ;;(set-terminal-coding-system 'euc-jp-unix)
  )
; ܸ info ʸʤ褦
(auto-compression-mode t)
; xemacs  shell-mode  ܸ EUC Ȥ褦ˤ
(if (featurep 'xemacs)
    (add-hook 'shell-mode-hook (function
       (lambda () (set-buffer-process-coding-system 'euc-japan 'euc-japan))))
)
; ܸ grep
(if (file-exists-p "/usr/bin/lgrep")
    (setq grep-command "lgrep -n ")
)
EOF

$emacs_comment = 
";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;";

#
#  ʴѴ
#
foreach $im ("Canna", "Wnn", "SKK", "Anthy", "PRIME") {
	&disp("$im NO JOUTAI: ", "$im ξ: ");
	if ($IM_EXIST{$im} == 0) {
		&disp("TSUKAEMASEN.\n", "Ȥޤ\n");
	} elsif ($IM_HOST{$im} eq "") {
		&disp("local\n", "\n");
	} else {
		&disp("host = $SERVER_HOST\n", "ۥ = $IM_HOST{$im}\n");
	}
}

$d = 6;
if ($IM_DEFAULT eq "Canna") {$d = 1;}
if ($IM_DEFAULT eq "Wnn")   {$d = 2;}
if ($IM_DEFAULT eq "SKK")   {$d = 3;}
if ($IM_DEFAULT eq "Anthy") {$d = 4;}
if ($IM_DEFAULT eq "PRIME") {$d = 5;}
$a = &select(
	"emacs DEHA, KANJI HENKAN NIHA DORE WO TSUKAI MASUKA? " .
	"1=Canna 2=Wnn 3=SKK 4=Anthy 5=PRIME 6=none ",
	"emacs ǤϡѴˤϤɤȤޤ " .
	"1=Canna 2=Wnn 3=SKK 4=Anthy 5=PRIME 6=none ",
	6, $d);
if ($a == 1) {
	&emacs_canna($IM_HOST{'Canna'});
} elsif ($a == 2) {
	&emacs_wnn($IM_HOST{'Wnn'});
} elsif ($a == 3) {
	&emacs_skk($IM_HOST{'SKK'});
} elsif ($a == 4) {
	&emacs_anthy;
} elsif ($a == 5) {
	&emacs_prime;
}

sub emacs_canna ($) {
	my $server;
	$server=$_[0];
	print
		"$emacs_comment\n" .
		";; Ѵ (canna) \n" .
		"$emacs_comment\n";
	if ($server ne "") {print "(setq canna-server \"$server\")";}
	print
		"(set-input-method 'japanese-canna)\n" .
		"(global-set-key \"\\C-o\" 'toggle-input-method)\n" .
		"(toggle-input-method nil)\n";
	addlist("xemacs21-mule-canna-wnn");
}

sub emacs_wnn($) {
	my $server;
	$server=$_[0];
	print
		"$emacs_comment\n" .
		";; Ѵ (wnn) \n" .
		"$emacs_comment\n" ;
	if ($server ne "") {print "(set-wnn-host-name \"$server\")\n";}
	print
		"(set-input-method 'japanese-egg-wnn)\n" .
		"(toggle-input-method nil)\n" ;
	addlist("xemacs21-mule-canna-wnn");
}

sub emacs_skk($) {
	my $server;
	$server=$_[0];
	system("/usr/bin/touch ~/.skk-jisyo");
	print
		"$emacs_comment\n" .
		";; Ѵ (skk) \n" .
		"$emacs_comment\n";
	if ($server ne "") {print "(setq skk-server-host \"$server\")\n";}
	print
		"(set-input-method \"japanese-skk\")\n" .
		"(toggle-input-method nil)\n";
	if (!isinstalled("xemacs21-mule.*")) {
		addlist("xemacs21-mule-canna-wnn");
	}
}

sub emacs_anthy {
	print
		"$emacs_comment\n" .
		";; Ѵ (Anthy) \n" .
		"$emacs_comment\n";
	print
		"(set-input-method \"japanese-anthy\")\n" .
		"(toggle-input-method nil)\n";
	addlist("anthy-el");
}

sub emacs_prime {
        print
		"$emacs_comment\n" .
		";; ʴѴ(PRIME)\n" .
		"$emacs_comment\n";
	print
		"(set-input-method \"japanese-prime\")\n" .
		"(toggle-input-method nil)\n";
	addlist("prime-el")
}

if (!$EXTENDED) {return;}
print <<'EOF';
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; XǤΥ顼ɽ
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(require 'font-lock)
(if (not (featurep 'xemacs))
    (global-font-lock-mode t)
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; C ץν
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;(defun my-c-mode-common-hook ()
;   (c-set-style "linux") (setq indent-tabs-mode t) ;linux Ȥ
;      /usr/src/linux/Documentation/CodingStyle 
;   (c-set-style "k&r") ;k&rȤϤͭˤ
;   (c-set-style "gnu") ;ǥեȤ
; )
;(add-hook 'c-mode-common-hook 'my-c-mode-common-hook)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Deleteǥ֤ʸä褦ˤ
(global-set-key [delete] 'delete-char)
;; C-h ǥκʸä褦ˤ롣
;; Ȥ C-h ϥإפʤΤǡ
;; ͭˤȡإפȤȤˤ
;; M-x help  F1 Ȥɬפޤ
;(global-set-key "\C-h" 'backward-delete-char)

EOF
